@@ -203,7 +203,7 @@ namespace AST
 
 		// if this is a multirange memory then this vector contains offset and length of each dimension
 		std::vector<int> multirange_dimensions;
-		std::vector<bool> multirange_swapped; // true if range is swapped, not used for structs
+		std::vector<bool> multirange_swapped; // true if range is swapped
 
 		// this is set by simplify and used during RTLIL generation
 		AstNode *id2ast;
@@ -268,6 +268,7 @@ namespace AST
 		struct varinfo_t {
 			RTLIL::Const val;
 			int offset;
+			bool range_swapped;
 			bool is_signed;
 			AstNode *arg = nullptr;
 			bool explicitly_sized;
